LINIE
=====

Overview
########

Spectroscopy lock application using RedPitaya.
Built with `Migen <https://github.com/m-labs/migen>`_, based on `RED PID <https://github.com/quartiq/redpid>`_.

Features
########


See Also
########
